==> nextcloud-app-spreed-1%3A6.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/eu.js <==
OC.L10N.register(
    "spreed",
    {
    "Participants" : "Partehartzaileak",
    "Chat" : "Chat",
    "Talk" : "Hitzaldi",
    "Copy" : "Kopiatu",
    "Copied!" : "Kopiatuta!",
    "Not supported!" : "Euskarririk gabe!",
    "Press ⌘-C to copy." : "Kopiatzeko ⌘-C to sakatu.",
    "Press Ctrl-C to copy." : "Kopiatzeko Ktrl -C sakatu.",
    "Request password" : "Eskatu pasahitza",
    "Please enter the password for this call" : "Dei honetarako pasahitza sartu mesedez",
    "Password required" : "Pasahitza beharrezkoa",
    "Password" : "Pasahitza",
    "Cancel" : "Ezeztatu",
    "Submit" : "Bidali",
    "Leave call" : "Deia utzi",
    "Join call" : "Deira lotu",
    "Start call" : "Hasi deia",
    "Share link" : "Esteka partekatu",
    "Change password" : "Pasahitza aldatu",
    "Set password" : "Ezarri pasahitza",
    "Name" : "Izena",
    "Rename" : "Abizena",
    "Copy link" : "Kopiatu esteka",
    "Link copied!" : "Esteka kopiatuta!",
    "You" : "Zu ",
    "No messages yet, start the conversation!" : "Ez dago mezurik, elkarrizketa hasi!",
    "New message …" : "Mezu berria...",
    "Send" : "Bidali",
    "Guest" : "Gonbidatua",
    "[Unknown user name]" : "[Erabiltzaile izen ezezaguna]",
    "Today" : "Gaur",
    "Yesterday" : "Atzo",
    "Error occurred while sending message" : "Mezua bidaltzean errorea egon da",
    "Edit" : "Editatu",
    "No other people in this call" : "Ez dago jenderik dei honetan",
    "Waiting for {participantName} to join the call …" : "{participantName}-ri itxoitzen deira gehitzeko",
    "Waiting for others to join the call …" : "Besteek deira gehitzera itxoiten...",
    "WebRTC is not supported in your browser :-/" : "Zure nabigatzaileak ez du WebRTC onartzen :-/",
    "Please use a different browser like Firefox or Chrome" : "Firefox edo Chrome bezalako nabigatzailea erabili",
    "Waiting for camera and microphone permissions" : "Kamera eta mikrofonoaren baimeneni itxoiten",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "App hau erabiltzeko mesedez, nabigatzaileari kamara eta mikroa erabiltzeko baimena eman. ",
    "Disable video" : "Bideoa desgaitu",
    "Share screen" : "Pantaila partekatu",
    "Show your screen" : "Idazmahaia erakutsi",
    "Stop screensharing" : "Pantaila partekatzeari utzi",
    "No audio" : "Audiorik ez",
    "No Camera" : "Kamerarik ez",
    "Screensharing is not supported by your browser." : "Zure nabigatzaileak ez du pantaila partekatzea onartzen",
    "Screensharing requires the page to be loaded through HTTPS." : "Pantaila partekatzeko webguneak  HTTPS erabili behar du. ",
    "Sharing your screen only works with Firefox version 52 or newer." : "Pantaila partekatzea Firefox 52 edo berriagoekin bakarrik funtzionatzen du",
    "Screensharing extension is required to share your screen." : "Pantaila partekatzeko pantailak partekatzeko luzapena instalatu behar da.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Pantaila partekatzeko Firefox edo Chrome erabil ezazu mesedez.",
    "An error occurred while starting screensharing." : "Pantaila partekatzean errore bat egon da.",
    "moderator" : "moderatzailea",
    "Demote from moderator" : "Moderatzailetik degradatua",
    "Promote to moderator" : "Moderatzaile bihurtu zara",
    "Remove participant" : "Partehartzailea borratu",
    "Favorited" : "Gogokoa",
    "Add to favorites" : "Gehitu gogokoetara",
    "Always notify" : "Jakinarazi beti",
    "Never notify" : "Ez jakinarazi inoiz",
    "Leave conversation" : "Atera elkarrizketatik",
    "Your screen" : "Zure pantaila",
    "{participantName}'s screen" : "{participantName}-aren pantaila",
    "Guest's screen" : "Gonbidatuaren pantaila",
    "Close" : "Itxi",
    "Show screen" : "Erakutsi pantaila",
    "Enable video" : "Aktibatu bideoa",
    "Access to microphone & camera is only possible with HTTPS" : "Kamara eta mikrofonoak atzitzeko modu bakarra HTTPS bidez da",
    "Access to microphone & camera was denied" : "Kamara eta mikrora sarrera debekatua",
    "WebRTC is not supported in your browser" : "Zure nabigatzaileak ez du WebRTC onartzen",
    "Error while accessing microphone & camera" : "Mikrofonoa eta kamara atzitzean errorea",
    "a conversation" : "elkarrizketa bat",
    "(Duration %s)" : "(Luzera %s)",
    "You attended a call with {user1}" : "{user1}-k egindako deia hartuta",
    "_%n guest_::_%n guests_" : ["%n gonbidatu","%n gonbidatu"],
    "You attended a call with {user1} and {user2}" : "{user1} eta {user2}ren deia jaso duzu",
    "You attended a call with {user1}, {user2} and {user3}" : "{user1}, {user2} eta {user3}ren deia jaso duzu",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "{user1}, {user2}, {user3} eta {user4}ren deia jaso duzu",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "{user1}, {user2}, {user3}, {user4} eta {user5}ren deia jaso duzu",
    "_%n other_::_%n others_" : ["beste %n ","beste %n "],
    "{actor} invited you to {call}" : "{actor} {call} deira gonbidatu zaitu",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "<strong> hitzaldi </strong> bat edo <strong>dei</strong> bat duzu",
    "You set a password" : "Pasahitz bat ezarri duzu",
    "Conversation not found" : "Elkarrizketa ez da aurkitu",
    "Validate SSL certificate" : "SSL ziurtagiria balidatu",
    "TURN server protocols" : "TURN zerbitzari protokoloak",
    "UDP and TCP" : "UDP eta TCP",
    "UDP only" : "UDP bakarrik",
    "TCP only" : "TCP bakarrik",
    "Saved" : "Gordeta",
    "Shared secret" : "Partekatutako sekretua",
    "STUN servers" : "STUN zerbitzariak",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN zerbitzariak router baten atzean dauden erabiltzaileen IP helbideak jakiteko erabiltzen da.",
    "The password is wrong. Try again." : "Pasahitza gaizki dago. Saiatu berriz",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Instalazio handientzako kanpo seinalizazio zerbitzaria erabil daiteke. Barne seinalizazio zerbitzaria erabiltzeko hutsik utzi",
    "TURN server" : "TURN zerbitzaria",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN zerbitzariak  firewall baten atzean dauden partehartzaileen trafikoa proxy bidez eramateko erabiltzen da",
    "Android app" : "Android aplikazioa",
    "iOS app" : "iOS aplikazioa",
    "Delete server" : "Zerbitzaria borratu",
    "Add new server" : "Zerbitzari berria gehitu",
    "TURN server shared secret" : "TURN zerbitzariaren partekatze-sekretua",
    "_%n other guest_::_%n other guests_" : ["%n gonbidatu","%n gonbidatu"],
    ", " : ", ",
    "This call is password-protected" : "Deia pasahitzarekin babestua dago",
    "Signaling server" : "Seinalizazio zerbitzaria ",
    "Join now" : "Elkartu orain"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A7.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/eu.js <==
OC.L10N.register(
    "spreed",
    {
    "{name} (public)" : "{name} (publikoa)",
    "Participants" : "Partehartzaileak",
    "Projects" : "Proiektuak",
    "Chat" : "Chat",
    "Talk" : "Hitzaldi",
    "Copy" : "Kopiatu",
    "Copied!" : "Kopiatuta!",
    "Not supported!" : "Euskarririk gabe!",
    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
    "Start a conversation" : "Hasi elkarrizketa bat",
    "Share" : "Partekatu",
    "Request password" : "Eskatu pasahitza",
    "Please enter the password for this call" : "Dei honetarako pasahitza sartu mesedez",
    "Password required" : "Pasahitza beharrezkoa",
    "Password" : "Pasahitza",
    "Cancel" : "Ezeztatu",
    "Submit" : "Bidali",
    "Leave call" : "Deia utzi",
    "Join call" : "Deira lotu",
    "Start call" : "Hasi deia",
    "Go to file" : "Joan fitxategira",
    "Share link" : "Esteka partekatu",
    "Copy link" : "Kopiatu esteka",
    "Change password" : "Pasahitza aldatu",
    "Set password" : "Ezarri pasahitza",
    "Name" : "Izena",
    "Rename" : "Aldatu izena",
    "Link copied!" : "Esteka kopiatuta!",
    "You" : "Zu ",
    "Guest" : "Gonbidatua",
    "No messages yet, start the conversation!" : "Ez dago mezurik, elkarrizketa hasi!",
    "New message …" : "Mezu berria...",
    "Send" : "Bidali",
    "[Unknown user name]" : "[Erabiltzaile izen ezezaguna]",
    "Today" : "Gaur",
    "Yesterday" : "Atzo",
    "Error occurred while sending message" : "Mezua bidaltzean errorea egon da",
    "Edit" : "Editatu",
    "No other people in this call" : "Ez dago jenderik dei honetan",
    "Waiting for {participantName} to join the call …" : "{participantName}-ri itxoitzen deira gehitzeko",
    "Waiting for others to join the call …" : "Besteek deira gehitzera itxoiten...",
    "WebRTC is not supported in your browser :-/" : "Zure nabigatzaileak ez du WebRTC onartzen :-/",
    "Please use a different browser like Firefox or Chrome" : "Firefox edo Chrome bezalako nabigatzailea erabili",
    "Waiting for camera and microphone permissions" : "Kamera eta mikrofonoaren baimeneni itxoiten",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "App hau erabiltzeko mesedez, nabigatzaileari kamara eta mikroa erabiltzeko baimena eman. ",
    "Mute audio" : "Mututu audioa",
    "Disable video" : "Bideoa desgaitu",
    "Share screen" : "Pantaila partekatu",
    "Show your screen" : "Idazmahaia erakutsi",
    "Stop screensharing" : "Pantaila partekatzeari utzi",
    "No audio" : "Audiorik ez",
    "No Camera" : "Kamerarik ez",
    "Screensharing is not supported by your browser." : "Zure nabigatzaileak ez du pantaila partekatzea onartzen",
    "Screensharing requires the page to be loaded through HTTPS." : "Pantaila partekatzeko webguneak  HTTPS erabili behar du. ",
    "Sharing your screen only works with Firefox version 52 or newer." : "Pantaila partekatzea Firefox 52 edo berriagoekin bakarrik funtzionatzen du",
    "Screensharing extension is required to share your screen." : "Pantaila partekatzeko pantailak partekatzeko luzapena instalatu behar da.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Pantaila partekatzeko Firefox edo Chrome erabil ezazu mesedez.",
    "An error occurred while starting screensharing." : "Pantaila partekatzean errore bat egon da.",
    "moderator" : "moderatzailea",
    "Demote from moderator" : "Moderatzailetik degradatua",
    "Promote to moderator" : "Moderatzaile bihurtu zara",
    "Remove participant" : "Partehartzailea borratu",
    "Favorited" : "Gogokoa",
    "Add to favorites" : "Gehitu gogokoetara",
    "All messages" : "Mezu guztiak",
    "Leave conversation" : "Atera elkarrizketatik",
    "Delete conversation" : "Ezabatu elkarrizketa",
    "Your screen" : "Zure pantaila",
    "{participantName}'s screen" : "{participantName}-aren pantaila",
    "Guest's screen" : "Gonbidatuaren pantaila",
    "Close" : "Itxi",
    "Show screen" : "Erakutsi pantaila",
    "Enable video" : "Aktibatu bideoa",
    "Access to microphone & camera is only possible with HTTPS" : "Kamara eta mikrofonoak atzitzeko modu bakarra HTTPS bidez da",
    "Access to microphone & camera was denied" : "Kamera eta mikrofonora sarbidea ukatu da",
    "WebRTC is not supported in your browser" : "Zure nabigatzaileak ez du WebRTC onartzen",
    "Error while accessing microphone & camera" : "Mikrofonoa eta kamara atzitzean errorea",
    "a conversation" : "elkarrizketa bat",
    "(Duration %s)" : "(Luzera %s)",
    "You attended a call with {user1}" : "{user1}-k egindako deia hartuta",
    "_%n guest_::_%n guests_" : ["%n gonbidatu","%n gonbidatu"],
    "You attended a call with {user1} and {user2}" : "{user1} eta {user2}ren deia jaso duzu",
    "You attended a call with {user1}, {user2} and {user3}" : "{user1}, {user2} eta {user3}ren deia jaso duzu",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "{user1}, {user2}, {user3} eta {user4}ren deia jaso duzu",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "{user1}, {user2}, {user3}, {user4} eta {user5}ren deia jaso duzu",
    "_%n other_::_%n others_" : ["beste %n ","beste %n "],
    "{actor} invited you to {call}" : "{actor} {call} deira gonbidatu zaitu",
    "You set a password" : "Pasahitz bat ezarri duzu",
    "You joined the conversation" : "Elkarrizketara elkartu zara",
    "You left the conversation" : "Elkarrizketatik atera zara",
    "Conversation invitation" : "Gonbidapena elkarrizketara",
    "Deleted user (%s)" : "Ezabatu erabiltzailea (%s)",
    "View chat" : "Ikusi txata",
    "Answer call" : "Erantzun deia",
    "Call back" : "Itzuli deia",
    "You missed a call from {user}" : "{user} erabiltzailearen dei bat galdu duzu",
    "Conversation not found" : "Elkarrizketa ez da aurkitu",
    "Validate SSL certificate" : "SSL ziurtagiria balidatu",
    "TURN server protocols" : "TURN zerbitzari protokoloak",
    "UDP and TCP" : "UDP eta TCP",
    "UDP only" : "UDP bakarrik",
    "TCP only" : "TCP bakarrik",
    "Test this server" : "Probatu zerbitzari hau",
    "Saved" : "Gordeta",
    "Shared secret" : "Partekatutako sekretua",
    "STUN servers" : "STUN zerbitzariak",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN zerbitzariak router baten atzean dauden erabiltzaileen IP helbideak jakiteko erabiltzen da.",
    "The password is wrong. Try again." : "Pasahitza gaizki dago. Saiatu berriz",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Instalazio handientzako kanpo seinalizazio zerbitzaria erabil daiteke. Barne seinalizazio zerbitzaria erabiltzeko hutsik utzi",
    "TURN server" : "TURN zerbitzaria",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN zerbitzariak  firewall baten atzean dauden partehartzaileen trafikoa proxy bidez eramateko erabiltzen da",
    "Android app" : "Android aplikazioa",
    "iOS app" : "iOS aplikazioa",
    "Delete server" : "Zerbitzaria borratu",
    "Add new server" : "Zerbitzari berria gehitu",
    "TURN server shared secret" : "TURN zerbitzariaren partekatze-sekretua",
    "Always notify" : "Jakinarazi beti",
    "Never notify" : "Ez jakinarazi inoiz",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "<strong> hitzaldi </strong> bat edo <strong>dei</strong> bat duzu",
    "_%n other guest_::_%n other guests_" : ["%n gonbidatu","%n gonbidatu"],
    ", " : ", ",
    "Join now" : "Elkartu orain",
    "This call is password-protected" : "Deia pasahitzarekin babestua dago",
    "Signaling server" : "Seinalizazio zerbitzaria "
},
"nplurals=2; plural=(n != 1);");
